diff --git a/Code/Mantid/Build/CMake/WindowsSetup.cmake b/Code/Mantid/Build/CMake/WindowsSetup.cmake
index 71655500c352fa6a4050f0337b3858cb2bfe077f..2b0646991a55d51297a453022df132651eb489b9 100644
--- a/Code/Mantid/Build/CMake/WindowsSetup.cmake
+++ b/Code/Mantid/Build/CMake/WindowsSetup.cmake
@@ -62,6 +62,8 @@ add_definitions ( -DWIN32 -D_WINDOWS -DMS_VISUAL_STUDIO )
 add_definitions ( -D_USE_MATH_DEFINES -DNOMINMAX )
 add_definitions ( -DGSL_DLL )
 add_definitions ( -DPOCO_NO_UNWINDOWS )
+add_definitions ( -D_SCL_SECURE_NO_WARNINGS )
+add_definitions ( -D_CRT_SECURE_NO_WARNINGS )
 
 set ( CONSOLE ON CACHE BOOL "Switch for enabling/disabling the console" )
 
diff --git a/Code/Mantid/Framework/API/inc/MantidAPI/ImplicitFunctionParameter.h b/Code/Mantid/Framework/API/inc/MantidAPI/ImplicitFunctionParameter.h
index 64d49f7f80a9009c8ba519920273dbcf76398b03..25e055f1e7a11bd7786c3622aa6e09369eab435f 100644
--- a/Code/Mantid/Framework/API/inc/MantidAPI/ImplicitFunctionParameter.h
+++ b/Code/Mantid/Framework/API/inc/MantidAPI/ImplicitFunctionParameter.h
@@ -4,6 +4,7 @@
 //----------------------------------------------------------------------
 // Includes
 //----------------------------------------------------------------------
+#include "MantidAPI/DllConfig.h"
 #include <Poco/DOM/Document.h>
 #include <Poco/DOM/Element.h>
 #include <Poco/DOM/Text.h>
@@ -13,7 +14,6 @@
 #include <sstream>
 #include <vector>
 #include <memory>
-#include "MantidAPI/DllConfig.h"
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/API/inc/MantidAPI/SpectraAxis.h b/Code/Mantid/Framework/API/inc/MantidAPI/SpectraAxis.h
index c1c88677738be49e4048e20506840fa32b27c276..5f462c58f028cc92827e2606b4ab23e8962d297e 100644
--- a/Code/Mantid/Framework/API/inc/MantidAPI/SpectraAxis.h
+++ b/Code/Mantid/Framework/API/inc/MantidAPI/SpectraAxis.h
@@ -76,7 +76,7 @@ public:
   void getSpectraIndexMap(spec2index_map&) const;
   void getIndexSpectraMap(index2spec_map& map) const;
 
-  void populateSimple(int64_t end);
+  void populateOneToOne(int64_t start, int64_t end);
 
 private:
   /// Default constructor
diff --git a/Code/Mantid/Framework/API/test/SpectraAxisTest.h b/Code/Mantid/Framework/API/test/SpectraAxisTest.h
index 5f9b12c4e0d8825d0bfaa4d9f90d093f8e8131b0..3f852529074c9279097113ebac3b3745bc7c8b56 100644
--- a/Code/Mantid/Framework/API/test/SpectraAxisTest.h
+++ b/Code/Mantid/Framework/API/test/SpectraAxisTest.h
@@ -85,12 +85,12 @@ public:
     delete one2one;
   }
 
-  void testPopulateSimple()
+  void testPopulateOneToOne()
   {
     SpectraAxis ax(5);
-    ax.populateSimple(100);
+    ax.populateOneToOne(1,100);
     TS_ASSERT_EQUALS( ax.length(), 100);
-    TS_ASSERT_EQUALS( ax.spectraNo(23), 23);
+    TS_ASSERT_EQUALS( ax.spectraNo(23), 24);
   }
 
   void testCopyConstructor()
diff --git a/Code/Mantid/Framework/Algorithms/src/ConvertSpectrumAxis.cpp b/Code/Mantid/Framework/Algorithms/src/ConvertSpectrumAxis.cpp
index 9dfbea05a30208b6e6f771312f3d74e1e7662b64..c5b73d4d475fcd152dde79344f81f95de1dc05a6 100644
--- a/Code/Mantid/Framework/Algorithms/src/ConvertSpectrumAxis.cpp
+++ b/Code/Mantid/Framework/Algorithms/src/ConvertSpectrumAxis.cpp
@@ -79,7 +79,7 @@ namespace Algorithms
     // Loop over the original spectrum axis, finding the theta (n.b. not 2theta!) for each spectrum
     // and storing it's corresponding workspace index
     // Map will be sorted on theta, so resulting axis will be ordered as well
-    std::multimap<double,int> indexMap;
+    std::multimap<double,size_t> indexMap;
     const size_t nHist = inputWS->getNumberHistograms();
     const size_t nBins = inputWS->blocksize();
     const bool isHist = inputWS->isHistogramData();
@@ -177,8 +177,8 @@ namespace Algorithms
     {
       newAxis->unit() = UnitFactory::Instance().create(unitTarget);
     }
-    std::multimap<double,int>::const_iterator it;
-    int currentIndex = 0;
+    std::multimap<double,size_t>::const_iterator it;
+    size_t currentIndex = 0;
     for (it = indexMap.begin(); it != indexMap.end(); ++it)
     {
       // Set the axis value
diff --git a/Code/Mantid/Framework/Algorithms/src/CreateGroupingWorkspace.cpp b/Code/Mantid/Framework/Algorithms/src/CreateGroupingWorkspace.cpp
index 34bf7a101b2b7006be399cb2bc270226fbec975d..48e766edc7f77dd6501cc3f12c3a1471dd80bab6 100644
--- a/Code/Mantid/Framework/Algorithms/src/CreateGroupingWorkspace.cpp
+++ b/Code/Mantid/Framework/Algorithms/src/CreateGroupingWorkspace.cpp
@@ -283,7 +283,7 @@ namespace Algorithms
         {
           outWS->setValue(detID, double(group));
         }
-        catch (std::invalid_argument & e)
+        catch (std::invalid_argument &)
         {
           numNotFound++;
         }
diff --git a/Code/Mantid/Framework/CurveFitting/inc/MantidCurveFitting/UserFunction1D.h b/Code/Mantid/Framework/CurveFitting/inc/MantidCurveFitting/UserFunction1D.h
index 47cbb625c8462b3b20f76034608a8179b524313f..3c2828346446974093a8e6d84ddb7f4cc8f4154e 100644
--- a/Code/Mantid/Framework/CurveFitting/inc/MantidCurveFitting/UserFunction1D.h
+++ b/Code/Mantid/Framework/CurveFitting/inc/MantidCurveFitting/UserFunction1D.h
@@ -5,7 +5,7 @@
 // Includes
 //----------------------------------------------------------------------
 #include "MantidCurveFitting/Fit1D.h"
-#include <muParser.h>
+#include "MantidGeometry/muParser_Silent.h"
 #include <boost/shared_array.hpp>
 
 namespace Mantid
diff --git a/Code/Mantid/Framework/CurveFitting/src/Convolution.cpp b/Code/Mantid/Framework/CurveFitting/src/Convolution.cpp
index 205bd421278f53ec8eafd3157ede90f38df0b2db..81196a5b00bf65b9529f560093247b6f79c650d2 100644
--- a/Code/Mantid/Framework/CurveFitting/src/Convolution.cpp
+++ b/Code/Mantid/Framework/CurveFitting/src/Convolution.cpp
@@ -1,5 +1,3 @@
-// To suppress STL warnings
-#define _SCL_SECURE_NO_WARNINGS
 //----------------------------------------------------------------------
 // Includes
 //----------------------------------------------------------------------
diff --git a/Code/Mantid/Framework/DataObjects/src/PeakColumn.cpp b/Code/Mantid/Framework/DataObjects/src/PeakColumn.cpp
index 34673dc85c93ad3f19ab989a3dddb0a139450ab6..092511194643a68ed0238f6f4e23eac36027438e 100644
--- a/Code/Mantid/Framework/DataObjects/src/PeakColumn.cpp
+++ b/Code/Mantid/Framework/DataObjects/src/PeakColumn.cpp
@@ -109,10 +109,10 @@ namespace DataObjects
 
     // Convert to a double
     double val = 0;
-    bool success = Strings::convert(text, val);
+    int success = Strings::convert(text, val);
     int ival = static_cast<int>(val);
 
-    if (!success)
+    if (success == 0)
     {
       g_log.error() << "Could not convert string '" << text << "' to a number.\n";
       return;
@@ -156,7 +156,7 @@ namespace DataObjects
   /// Must return overall memory size taken by the column.
   long int PeakColumn::sizeOfData()const
   {
-    return sizeof(double) * peaks.size();
+    return sizeof(double) * static_cast<long int>(peaks.size());
   }
 
 
diff --git a/Code/Mantid/Framework/DataObjects/src/Workspace1D.cpp b/Code/Mantid/Framework/DataObjects/src/Workspace1D.cpp
index 678bf17fe0cf7435826a45b55b6c8d9d90d8ff37..056c854579221a218cdcdcdc34295dea33c77bc1 100644
--- a/Code/Mantid/Framework/DataObjects/src/Workspace1D.cpp
+++ b/Code/Mantid/Framework/DataObjects/src/Workspace1D.cpp
@@ -61,7 +61,7 @@ namespace Mantid
      */
     size_t Workspace1D::blocksize() const
     {
-      int retVal = 1000000000;
+      size_t retVal = 1000000000;
       //if not empty
       if (size() > 0)
       {
diff --git a/Code/Mantid/Framework/Geometry/src/MDGeometry/MDGeometryXMLParser.cpp b/Code/Mantid/Framework/Geometry/src/MDGeometry/MDGeometryXMLParser.cpp
index 6f8bdd078413c42b7e7cb9fd599f5b1980dddf46..db6c327a034c3cb20176a643c4d7adfb0aac4b33 100644
--- a/Code/Mantid/Framework/Geometry/src/MDGeometry/MDGeometryXMLParser.cpp
+++ b/Code/Mantid/Framework/Geometry/src/MDGeometry/MDGeometryXMLParser.cpp
@@ -86,7 +86,7 @@ namespace Mantid
         ////Extract dimensions
         for (size_t i = 0; i < nDimensions; i++)
         {
-          Poco::XML::Element* dimensionXML = static_cast<Poco::XML::Element*> (dimensionsXML->item(i));
+          Poco::XML::Element* dimensionXML = static_cast<Poco::XML::Element*> (dimensionsXML->item(static_cast<unsigned long>(i)));
           Mantid::Geometry::IMDDimensionFactory factory(dimensionXML);
           Mantid::Geometry::IMDDimension* dimension = factory.create();
           vecAllDims[i] = boost::shared_ptr<Mantid::Geometry::IMDDimension>(dimension);
diff --git a/Code/Mantid/Framework/Kernel/src/PropertyManager.cpp b/Code/Mantid/Framework/Kernel/src/PropertyManager.cpp
index 75da06c4a862daa63e071d34582b3de6d8972010..733bd53c110727a4a7810c3ca4bb9f50c2e71945 100644
--- a/Code/Mantid/Framework/Kernel/src/PropertyManager.cpp
+++ b/Code/Mantid/Framework/Kernel/src/PropertyManager.cpp
@@ -96,7 +96,7 @@ namespace Mantid
           //Use the property's += operator to add THAT. Isn't abstraction fun?!
           (*lhs_prop) += it->second;
         }
-        catch (Exception::NotFoundError & err)
+        catch (Exception::NotFoundError &)
         {
           //The property isnt on the lhs.
           //Let's copy it
diff --git a/Code/Mantid/Framework/Kernel/src/VectorHelper.cpp b/Code/Mantid/Framework/Kernel/src/VectorHelper.cpp
index f8065516efb4cac195e193b0c927bffec1625c48..fdd3305ad7dbf4293f8083785d278b9aeaa57337 100644
--- a/Code/Mantid/Framework/Kernel/src/VectorHelper.cpp
+++ b/Code/Mantid/Framework/Kernel/src/VectorHelper.cpp
@@ -1,6 +1,3 @@
-// define placed here to suppress boost library warning
-#define _SCL_SECURE_NO_WARNINGS
-
 #include <stdexcept>
 #include <cmath>
 
diff --git a/Code/Mantid/Framework/MDAlgorithms/inc/MantidMDAlgorithms/CompositeImplicitFunction.h b/Code/Mantid/Framework/MDAlgorithms/inc/MantidMDAlgorithms/CompositeImplicitFunction.h
index 499e9af4beb607e0fcbb9ecaf359fd1d9846d67e..48eb237a891b3c243e4764273089cad89bca92e2 100644
--- a/Code/Mantid/Framework/MDAlgorithms/inc/MantidMDAlgorithms/CompositeImplicitFunction.h
+++ b/Code/Mantid/Framework/MDAlgorithms/inc/MantidMDAlgorithms/CompositeImplicitFunction.h
@@ -5,9 +5,9 @@
 // Includes
 //----------------------------------------------------------------------
 #include <vector>
+#include "MantidAPI/ImplicitFunction.h"
 #include "MantidKernel/System.h"
 #include <boost/shared_ptr.hpp>
-#include "MantidAPI/ImplicitFunction.h"
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/BoxImplicitFunction.cpp b/Code/Mantid/Framework/MDAlgorithms/src/BoxImplicitFunction.cpp
index b8f46a212ef60f8302d541d37b1c69ab13bddec8..893cf4a0c0a8e1aa0a6eb3721eda0e42b7183f4e 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/BoxImplicitFunction.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/BoxImplicitFunction.cpp
@@ -1,7 +1,7 @@
-#include <boost/algorithm/string.hpp>
-#include <boost/format.hpp>
 #include "MantidMDAlgorithms/BoxImplicitFunction.h"
 #include "MantidAPI/Point3D.h"
+#include <boost/algorithm/string.hpp>
+#include <boost/format.hpp>
 #include <cmath>
 #include <vector>
 
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/DepthParameter.cpp b/Code/Mantid/Framework/MDAlgorithms/src/DepthParameter.cpp
index 1f4b156d566c4a147b2ece50fde5c271a6151673..5f1b1c60f9397ff91743a8476aa201572e63ac17 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/DepthParameter.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/DepthParameter.cpp
@@ -1,6 +1,6 @@
+#include "MantidMDAlgorithms/DepthParameter.h"
 #include <boost/algorithm/string.hpp>
 #include <boost/format.hpp>
-#include "MantidMDAlgorithms/DepthParameter.h"
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/HeightParameter.cpp b/Code/Mantid/Framework/MDAlgorithms/src/HeightParameter.cpp
index abcde0622f0df8b8cd8781d7528f4d67da5a81e4..be876b20f735140db70b250dee31432a320eadca 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/HeightParameter.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/HeightParameter.cpp
@@ -1,6 +1,6 @@
+#include "MantidMDAlgorithms/HeightParameter.h"
 #include <boost/algorithm/string.hpp>
 #include <boost/format.hpp>
-#include "MantidMDAlgorithms/HeightParameter.h"
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/NormalParameter.cpp b/Code/Mantid/Framework/MDAlgorithms/src/NormalParameter.cpp
index 66bec0db20aeca29e97bdaf5256249826d53a127..733b4c081223473a70d4fbdb3341ffd6b1c595b8 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/NormalParameter.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/NormalParameter.cpp
@@ -1,7 +1,7 @@
-#include <boost/algorithm/string.hpp>
-#include <boost/format.hpp>
 #include "MantidMDAlgorithms/NormalParameter.h"
 #include <cmath>
+#include <boost/algorithm/string.hpp>
+#include <boost/format.hpp>
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/OriginParameter.cpp b/Code/Mantid/Framework/MDAlgorithms/src/OriginParameter.cpp
index dc4a92725f81e9724f656c94732a21d7eeffad7c..5c461115649ddf66bb26ad6b4324d0122c947dd8 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/OriginParameter.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/OriginParameter.cpp
@@ -1,6 +1,6 @@
+#include "MantidMDAlgorithms/OriginParameter.h"
 #include <boost/algorithm/string.hpp>
 #include <boost/format.hpp>
-#include "MantidMDAlgorithms/OriginParameter.h"
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/PerpendicularParameter.cpp b/Code/Mantid/Framework/MDAlgorithms/src/PerpendicularParameter.cpp
index e0ed27e2780b68a6eab3fb81ba23c956195941a2..4ab1e7314a48bd81a109b9b897261ff78124dbc2 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/PerpendicularParameter.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/PerpendicularParameter.cpp
@@ -1,6 +1,6 @@
+#include "MantidMDAlgorithms/PerpendicularParameter.h"
 #include <boost/algorithm/string.hpp>
 #include <boost/format.hpp>
-#include "MantidMDAlgorithms/PerpendicularParameter.h"
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/PlaneImplicitFunction.cpp b/Code/Mantid/Framework/MDAlgorithms/src/PlaneImplicitFunction.cpp
index 06051e97db1755ec019c9324a2910959846118f0..10b4f16cdd6ecde2dec53019efb817598df785f0 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/PlaneImplicitFunction.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/PlaneImplicitFunction.cpp
@@ -1,10 +1,11 @@
-#include <boost/algorithm/string.hpp>
-#include <boost/format.hpp>
 #include "MantidMDAlgorithms/PlaneImplicitFunction.h"
 #include "MantidAPI/Point3D.h"
 #include "MantidGeometry/V3D.h"
 #include <cmath>
 #include <vector>
+#include <boost/algorithm/string.hpp>
+#include <boost/format.hpp>
+
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/UpParameter.cpp b/Code/Mantid/Framework/MDAlgorithms/src/UpParameter.cpp
index ae79543ce981bbe29d5bff1a9c1b34fe506e2195..8308119653f5357e9038da214a62e981870000c5 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/UpParameter.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/UpParameter.cpp
@@ -1,7 +1,7 @@
-#include <boost/algorithm/string.hpp>
-#include <boost/format.hpp>
 #include "MantidMDAlgorithms/UpParameter.h"
 #include <cmath>
+#include <boost/algorithm/string.hpp>
+#include <boost/format.hpp>
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDAlgorithms/src/WidthParameter.cpp b/Code/Mantid/Framework/MDAlgorithms/src/WidthParameter.cpp
index 3540ab719c4c6ccb42c0079375b2e27c5dce8ff0..5b6eab4f8cc8bfbaae30987826710ea1dffe6b2c 100644
--- a/Code/Mantid/Framework/MDAlgorithms/src/WidthParameter.cpp
+++ b/Code/Mantid/Framework/MDAlgorithms/src/WidthParameter.cpp
@@ -1,6 +1,6 @@
+#include "MantidMDAlgorithms/WidthParameter.h"
 #include <boost/algorithm/string.hpp>
 #include <boost/format.hpp>
-#include "MantidMDAlgorithms/WidthParameter.h"
 
 namespace Mantid
 {
diff --git a/Code/Mantid/Framework/MDEvents/src/MDEventWorkspace.cpp b/Code/Mantid/Framework/MDEvents/src/MDEventWorkspace.cpp
index 18b76fdbba76df750a5b1615b418d5470971a4ed..391f0b4b08fe7bedb214c315f6ab9ff8e8777370 100644
--- a/Code/Mantid/Framework/MDEvents/src/MDEventWorkspace.cpp
+++ b/Code/Mantid/Framework/MDEvents/src/MDEventWorkspace.cpp
@@ -390,7 +390,7 @@ namespace MDEvents
           dimensionToBinFrom.push_back(dim_index);
           binDimensions.push_back(binDimensionsIn[i]);
         }
-        catch (std::runtime_error & e)
+        catch (std::runtime_error &)
         {
           // The dimension was not found, so we are not binning across it. TODO: Log message?
           if (binDimensionsIn[i]->getNBins() > 1)
diff --git a/Code/Mantid/Framework/Nexus/test/SaveNexusProcessedTest.h b/Code/Mantid/Framework/Nexus/test/SaveNexusProcessedTest.h
index 7c48a61a1ccab6867694cf186609f1f06ae1a130..e56be7184d735826ce0989fe4feca3d861822849 100644
--- a/Code/Mantid/Framework/Nexus/test/SaveNexusProcessedTest.h
+++ b/Code/Mantid/Framework/Nexus/test/SaveNexusProcessedTest.h
@@ -1,15 +1,6 @@
 #ifndef SAVENEXUSPROCESSEDTEST_H_
 #define SAVENEXUSPROCESSEDTEST_H_
 
-
-//TODO: Remove this before checking in the test
-//#define _WIN64
-
-
-
-#include <fstream>
-#include <cxxtest/TestSuite.h>
-
 // These includes seem to make the difference between initialization of the
 // workspace names (workspace2D/1D etc), instrument classes and not for this test case.
 #include "MantidDataObjects/WorkspaceSingleValue.h"
@@ -31,6 +22,10 @@
 #include <Poco/File.h>
 #include <Poco/Path.h>
 
+#include <fstream>
+#include <cxxtest/TestSuite.h>
+
+
 using namespace Mantid::API;
 using namespace Mantid::Kernel;
 using namespace Mantid::NeXus;
diff --git a/Code/Mantid/Framework/PythonAPI/src/api_exports.cpp b/Code/Mantid/Framework/PythonAPI/src/api_exports.cpp
index a852591f87e3656172a220f8d8a607c9f865d84e..753d0d06f0b1d6b26bf4c5d438ae112796939249 100644
--- a/Code/Mantid/Framework/PythonAPI/src/api_exports.cpp
+++ b/Code/Mantid/Framework/PythonAPI/src/api_exports.cpp
@@ -442,9 +442,9 @@ using namespace boost::python;
       ;
     // Spectra Axis subclass
     class_< API::SpectraAxis, bases<API::Axis>, boost::noncopyable >("SpectraAxis", no_init)
-      .def("spectraNumber", (const specid_t & (Mantid::API::SpectraAxis::*)(const size_t &) const) & API::SpectraAxis::spectraNo, return_value_policy<copy_const_reference>() ) // (const int & (Mantid::API::SpectraAxis::*)() const)
+      .def("spectraNumber", (const specid_t & (Mantid::API::SpectraAxis::*)(const size_t &) const) & API::SpectraAxis::spectraNo, return_value_policy<copy_const_reference>() )
       .def("setValue", & API::SpectraAxis::setValue)
-      .def("populateSimple", & API::SpectraAxis::populateSimple)
+      .def("populateOneToOne", & API::SpectraAxis::populateOneToOne)
       ;
     // Text Axis subclass
     class_< API::TextAxis, bases<API::Axis>, boost::noncopyable >("TextAxis", no_init)
diff --git a/Code/Mantid/Framework/API/src/SpectraAxis.cpp b/Code/Mantid/Framework/API/src/SpectraAxis.cpp
index 92bf0fb7243d88ab419abde2c8eecd03f27a68e0..ef73309b261ccf43d9511c59f54e3f695d2b4be6 100644
--- a/Code/Mantid/Framework/API/src/SpectraAxis.cpp
+++ b/Code/Mantid/Framework/API/src/SpectraAxis.cpp
@@ -158,7 +158,7 @@ void SpectraAxis::getIndexSpectraMap(index2spec_map& map)const
   map.clear();
   for (size_t i=0; i < nel; ++i )
   {
-    map.insert(std::make_pair<int64_t,int64_t>(i, m_values[i]));
+    map.insert(std::make_pair<size_t,specid_t>(i, m_values[i]));
   }
 }
 
@@ -176,17 +176,25 @@ void SpectraAxis::getSpectraIndexMap(spec2index_map& map)const
   map.clear();
   for (size_t i=0; i < nel; ++i )
   {
-    map.insert(std::make_pair<int64_t,int64_t>(m_values[i],i));
+    map.insert(std::make_pair<specid_t,size_t>(m_values[i],i));
   }
 }
 
 /** Populate the SpectraAxis with a simple 1:1 map from 0 to end-1.
  */
-void SpectraAxis::populateSimple(int64_t end)
+void SpectraAxis::populateOneToOne(int64_t start, int64_t end)
 {
-  m_values.resize(static_cast<size_t>(end), 0);
-  for (int64_t i=0; i < end; i++)
-    m_values[i] = static_cast<specid_t>(i);
+  if( start > end )
+  {
+    throw std::invalid_argument("SpectraAxis::populateOneToOne - start > end");
+  }
+  const size_t nvalues(end-start+1);
+  m_values.resize(nvalues, 0);
+  for (size_t i=0; i < nvalues; i++)
+  {
+    m_values[i] = static_cast<specid_t>(start+i);
+  }
 }
 
 
@@ -176,17 +176,25 @@ void SpectraAxis::getSpectraIndexMap(spec2index_map& map)const
 }
 
-/** Populate the SpectraAxis with a simple 1:1 map from 0 to end-1.
+/** 
+ * Populate the SpectraAxis with a 1:1 map from start to end (inclusive).
  */